#!/usr/bin/python

from ConfigParser import RawConfigParser
import gtk
import os

global home
home = os.getenv("HOME")
global config_dir
config_dir = "/".join([home, ".config/lsc"])
global data_system_path
data_system_path = "/usr/share/LSC/"
default_conf_file = '''
[General]
ui_path = data/lsc.ui
preferences_ui = data/preferences.ui
infos_ui = data/infos.ui
app_install_directory = /usr/share/app-install/desktop/
expert_mode = FALSE
categories_file = data/categories
categories_file_expert = data/categories_expert
'''


if not os.path.exists("/".join([config_dir, "LSC.ini"])):
    print("Creating new conf file in %s" % "/".join([config_dir, "LSC.ini"]))
    os.mkdir("/".join([home, ".config/lsc"]))
    file = open("/".join([config_dir, "LSC.ini"]), "w")
    file.write(default_conf_file)
    file.close()

class Controller:
    def __init__(self):
        print("Opening config file")
        self.home = home
        self.conf_dir = config_dir
        self.file_path = "/".join([config_dir, "LSC.ini"])
        self.conf_file = open(self.file_path, "r+w")
        self.parser = RawConfigParser()
        self.parser.readfp(self.conf_file)

        if os.path.isfile(self.parser.get("General", "UI_PATH")):
            self.UI_PATH = self.parser.get("General", "UI_PATH")
        else:
            self.UI_PATH = os.path.join(data_system_path,"lsc.ui")

        if os.path.isfile(self.parser.get("General", "PREFERENCES_UI")):
            self.PREFERENCES_UI = self.parser.get("General", "PREFERENCES_UI")
        else:
            self.PREFERENCES_UI = os.path.join(data_system_path,"preferences.ui")

        if os.path.isfile(self.parser.get("General", "INFOS_UI")):
            self.INFOS_UI = self.parser.get("General", "INFOS_UI")
        else:
            self.INFOS_UI = os.path.join(data_system_path,"infos.ui")

        self.app_install_directory = self.parser.get("General", "app_install_directory")

        self.expert_mode = self.parser.getboolean("General", "expert_mode")

        if os.path.isfile(self.parser.get("General", "categories_file")):
            self.categories_file = open(self.parser.get("General", "categories_file"), "r")
        else:
            self.categories_file = open(os.path.join(data_system_path,"categories"), "r")

    def append_categories(self, ui, model):
        model.clear()
        ui.categories_dict = {}
        if not self.expert_mode:
            for lines in self.categories_file:
                string = lines.split("||")
                ui.categories_dict[string[0]] = [string[1], string[2]]
            for items in ui.categories_dict:
                if items != "All":
                    model.append([items, ui.categories_dict[items][0], ui.categories_dict[items][1], 5])
        else:
            for lines in self.categories_file:
                string = lines.split("||")
                ui.categories_dict[string[0]] = [string[1], string[3].replace("\n", "")]
            for items in ui.categories_dict:
                if items != "All":
                    model.append([items, ui.categories_dict[items][0], ui.categories_dict[items][1], 5])
        model.append(["All", "distributor-logo", "all", 5])
        self.categories_file.close()

def __init__():
    global controller
    controller = Controller()
